<template>
    <div>
        <el-dialog :title="title" :visible="visible" :before-close="handleClose" :close-on-click-modal="false" width="86%"
            top="5vh">
            <el-form :model="annualValue" ref="numberValidateForm" :show-message="false" :rules="rules">
                <el-table stripe height="45vh" size="mini" v-loading="loading" ref="multipleSelection"
                    :data="annualValue.tableData" :style="{ width: '100%' }" class="my-el-table">
                    <el-table-column align="center" width="60" v-if="!disabled" fixed="left">
                        <!-- <template
                            slot="header"
                            v-if="!annualValue.tableData.length"
                        >
                            <i class="el-icon-plus add-btn" @click="addTable" />
                        </template> -->
                        <template slot-scope="scope">
                            <i class="el-icon-plus add-btn" @click="addTable"></i>
                            <i class="el-icon-delete" style="
                                    color: red;
                                    margin-left: 10px;
                                    display: inline-block;
                                    cursor: pointer;
                                " v-if="!disabled" @click="edlTable(scope.$index)"></i>
                        </template>
                    </el-table-column>
                    <!-- <el-table-column
                        type="index"
                        width="55"
                        label="序号"
                        align="center"
                        fixed="left"
                    ></el-table-column> -->
                    <el-table-column prop="year" label="年份" min-width="100" align="center" fixed="left">
                        <template v-slot="{ row, $index }">
                            <span v-if="disabled">
                                {{ row.year }}
                            </span>
                            <el-form-item v-else :prop="'tableData.' + $index + '.year'" :rules="rules.year">
                                <el-date-picker v-model="row.year" type="year" value-format="yyyy" format="yyyy"
                                    style="width: 100%" placeholder="选择年份">
                                </el-date-picker>
                            </el-form-item>
                        </template>
                    </el-table-column>
                    <el-table-column prop="yearValue" label="年度目标值" align="center" fixed="left">
                        <template v-slot="{ row, $index }">
                            <span v-if="disabled">
                                {{ row.yearValue }}
                            </span>
                            <el-form-item v-else :prop="'tableData.' + $index + '.yearValue'" :rules="rules.yearValue">
                                <el-input @input="validateNum($event, $index, 'yearValue')" :rules="rules.yearValue" v-model.trim="row.yearValue" type="text"
                                    :disabled="disabled" />
                            </el-form-item>
                        </template>
                    </el-table-column>
                    <el-table-column v-for="(item, index) in tableOptions" :key="index" :prop="item"
                        :label="index + 1 + `月`" min-width="80" align="center">
                        <template v-slot="{ row, $index }">
                            <span v-if="disabled" :title="row[item]">
                                {{ row[item] }}
                            </span>
                            <el-form-item v-else :prop="'tableData.' + $index + `.${item}`" :rules="rules.numValue">
                                <el-input v-model="row[item]"
                                    @input="validateNum($event, $index, item)" type="text" :disabled="disabled" />
                            </el-form-item>
                        </template>
                    </el-table-column>
                </el-table>
            </el-form>
            <span slot="footer" class="dialog-footer">
                <el-button type="primary" @click="handleSave" v-if="!this.disabled">保存</el-button>
                <el-button @click="handleClose">取消</el-button>
            </span>
        </el-dialog>
    </div>
</template>

<script>
import org from '@/api/org.js'
import utils from '@/utils.js'
import dictUtils from '@/components/dict/DictSelectUtils.js'
import majorProjects from '@/api/MajorReformProjects/majorProjects.js'

export default {
    name: 'targetDialog',
    data() {
        var checkYear = (rule, value, callback) => {
            let yearArr = this.annualValue.tableData.map((item) => item.year)
            console.log(yearArr)
            if (yearArr.indexOf(value) !== yearArr.lastIndexOf(value)) {
                this.$message.warning('该年份已存在请重新选择')
                callback(new Error('该年份已存在请重新选择'))
            } else {
                callback()
            }
        }
        return {
            visible: false,
            title: '量化值录入',
            loading: false,
            disabled: false,
            annualValue: {
                tableData: [
                    //   {
                    //     year: new Date().getFullYear() + ''
                    //   }
                ],
            },

            queryParam: {
                pageBean: {
                    page: 1,
                    pageSize: -1,
                },
            },
            index: '',
            rules: {
                numValue: [
                    { required: true, trigger: 'blur' },
                    { pattern: /^[0-9]+(\.[0-9]{1,3})?$/, trigger: 'blur' },
                ],
                year: [
                    { required: true, trigger: 'blur' },
                    { validator: checkYear, trigger: 'blur' },
                ],
                yearValue: [
                    { required: true, trigger: 'blur' },
                    { pattern: /^[0-9]+(\.[0-9]{1,3})?$/, trigger: 'blur' },
                ],
            },
            tableOptions: [
                'janValue',
                'febValue',
                'marValue',
                'aprValue',
                'mayValue',
                'junValue',
                'julValue',
                'augValue',
                'sepValue',
                'octValue',
                'novValue',
                'decValue',
            ],
        }
    },
    created() { },
    mounted() { },
    methods: {
        validateNum(val, index, key) {
            val = val.replace(/^(\d*\.?\d{0,3}).*/,'$1')
            if (!val) {
                this.annualValue.tableData[index][key] = "";
                return
            }
            console.log(val);
            this.annualValue.tableData[index][key] = val;
        },
        add(ind, val, title) {
            this.index = ind
            let obj = { yearValue: 0 }
            this.tableOptions.forEach((name) => {
                obj[name] = 0
            })
            if (val.pilotObjectivesDetailsList) {
                val.pilotObjectivesDetailsList.forEach((item) => {
                    item.year = item.year + ''
                })
                this.annualValue.tableData = val.pilotObjectivesDetailsList
            }
            if (!this.annualValue.tableData.length) {
                this.annualValue.tableData = [
                    {
                        year: new Date().getFullYear() + '',
                        ...obj,
                    },
                ]
            }
            this.disabled = title == '详情' ? true : false
            this.title = '量化值目标值' + title
            this.visible = true
        },
        // 关闭新增人员窗口
        handleClose() {
            this.visible = false
            this.disabled = false
            //   this.tableData = [
            //     {
            //       year: new Date().getFullYear() + ''
            //     }
            //   ]
            this.annualValue = {
                tableData: [
                    //   {
                    //     year: new Date().getFullYear() + ''
                    //   }
                ],
            }
        },
        // 保存
        handleSave() {
            this.$refs.numberValidateForm.validate((valid) => {
                if (valid) {
                    this.$emit(
                        'addData',
                        this.annualValue.tableData,
                        this.index
                    )
                    this.handleClose()
                } else {
                    this.$message.warning('量化目标值录入有误，请检查后保存')
                }
            })

            //
        },
        addTable() {
            let obj = { yearValue: 0 }
            this.tableOptions.forEach((name) => {
                obj[name] = 0
            })
            let temp = this.annualValue.tableData
            temp.push({
                year:
                    new Date().getFullYear() -
                    this.annualValue.tableData.length +
                    '',
                ...obj,
            })
            this.annualValue.tableData = temp
        },
        edlTable(index) {
            if (this.annualValue.tableData.length > 1) {
                this.annualValue.tableData.splice(index, 1)
            } else {
                this.$message.warning('至少保留一条目标值数据！')
                // this.annualValue.tableData = [
                //     {
                //         year: new Date().getFullYear() + '',
                //     },
                // ]
            }
            console.log(this.tableData)
        },
    },
}
</script>

<style lang="scss" scoped>
@import '~@/assets/css/element-variables.scss';

.add-btn {
    font-weight: bold;
    cursor: pointer;
    color: $--color-primary;
}

.del-btn {
    font-weight: bold;
    margin-left: 10px;
    color: $--color-danger;
    cursor: pointer;
}

/deep/.el-dialog__body {
    max-height: 600px;
    overflow-y: auto;
}

.my-el-table {
    /deep/.el-form-item {
        margin-bottom: 0;
    }

    /deep/.el-form-item.is-error {
        margin-bottom: 0;
    }
}
</style>
